@@ -529,9 +529,7 @@ class Storage(storage.Storage):
 
 
         # get tags from database - this will create any missing tags too
-        tags = [dict(zip(('id', 'name', 'autocomplete'), row))
-                                           for row in self.GetTagIds(fact.tags)]
-
+        tags = [(tag['id'], tag['name'], tag['autocomplete']) for tag in self.get_tag_ids(fact.tags)]
 
         # now check if maybe there is also a category
         category_id = None
@@ -630,8 +628,11 @@ class Storage(storage.Storage):
 
 
     def __get_todays_facts(self):
-        from configuration import conf
-        day_start = conf.get("day_start_minutes")
+        try:
+            from configuration import conf
+            day_start = conf.get("day_start_minutes")
+        except:
+            day_start = 5 * 60 # default day start to 5am
         day_start = dt.time(day_start / 60, day_start % 60)
         today = (dt.datetime.now() - dt.timedelta(hours = day_start.hour,
                                                   minutes = day_start.minute)).date()
@@ -639,8 +640,11 @@ class Storage(storage.Storage):
 
 
     def __get_facts(self, date, end_date = None, search_terms = ""):
-        from configuration import conf
-        day_start = conf.get("day_start_minutes")
+        try:
+            from configuration import conf
+            day_start = conf.get("day_start_minutes")
+        except:
+            day_start = 5 * 60 # default day start to 5am
         day_start = dt.time(day_start / 60, day_start % 60)
 
         split_time = day_start
